@@ -274,11 +274,7 @@ bool KviHttpRequest::event(TQEvent *e)
 			case KVI_HTTP_REQUEST_THREAD_EVENT_REQUESTSENT:
 			{
 				TQString * req = ((KviThreadDataEvent<TQString> *)e)->getData();
-#ifdef COMPILE_USE_QT4
-				TQStringList sl = req->split("\r\n");
-#else
 				TQStringList sl = TQStringList::split("\r\n",*req);
-#endif
 				emit requestSent(sl);
 				delete req;
 				return true;
