@@ -50,7 +50,7 @@ class KviHttpRequestThread;
 
 class KVILIB_API KviHttpRequest : public TQObject, public KviHeapObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	enum ProcessingType
