@@ -28,7 +28,7 @@
 
 class KVILIB_API KviTalFileDialog : public KFileDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTalFileDialog(const TQString &dirName,const TQString &filter = TQString(),TQWidget *parent = 0,const char *name = 0,bool modal = FALSE);
