@@ -29,7 +29,7 @@
 
 class KVILIB_API KviTalGrid : public TQGrid
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTalGrid(int n,Qt::Orientation orient,TQWidget * pParent = 0)
