@@ -90,9 +90,6 @@
 #include <tqstringlist.h>
 #include "kvi_pointerhashtable.h"
 #include <tqmime.h>
-#ifdef COMPILE_USE_QT4
-	#include <tq3mimefactory.h>
-#endif
 #include "kvi_tal_listbox.h"
 #include <tqclipboard.h>
 #include <tqmessagebox.h>
@@ -103,17 +100,8 @@
 	#include "kvi_ssl.h"
 #endif
 
-#ifdef COMPILE_USE_QT4
-#ifdef COMPILE_ON_WINDOWS
-#include <TQPluginLoader>
-#endif
-#endif
 
-#ifdef COMPILE_USE_QT4
-	#include <TQTextDocument>
-#else
 	#include <tqstylesheet.h>
-#endif
 
 KVIRC_API KviApp                       * g_pApp                    = 0; // global application pointer
 
@@ -223,16 +211,6 @@ void KviApp::setup()
 	loadDirectories();
 	KviStringConversion::init(m_szGlobalKvircDir,m_szLocalKvircDir);
 
-#ifdef COMPILE_USE_QT4
-#ifdef COMPILE_ON_WINDOWS
-	//need to load image plugins:(
-	TQString szPluginsDir;
-	getGlobalKvircDirectory(szPluginsDir,None,"qt-plugins/");
-	setLibraryPaths(TQStringList(szPluginsDir));
-	//KviMessageBox::information(libraryPaths().join(";"));
-	//tqDebug("%1",loader.isLoaded());
-#endif
-#endif
 
 	// check if we want to permanently disable the splash screen
 	// we do it once for every version: the user should see the new splash screens at least once
@@ -269,11 +247,7 @@ void KviApp::setup()
 	list.append(tmp);
 	getGlobalKvircDirectory(tmp,HelpNoIntl);
 	list.append(tmp);
-#ifdef COMPILE_USE_QT4
-	Q3MimeSourceFactory::defaultFactory()->setFilePath(list);
-#else
 	TQMimeSourceFactory::defaultFactory()->setFilePath(list);
-#endif
 
 	KVI_SPLASH_SET_PROGRESS(1)
 
@@ -475,18 +449,6 @@ void KviApp::setup()
 
 	KviDoubleBuffer::init();
 
-#ifdef COMPILE_USE_QT4
-	TQString szStylesheetFile;
-	getGlobalKvircDirectory(szStylesheetFile,Config,"style.css");
-	if(KviFileUtils::fileExists(szStylesheetFile))
-	{
-		TQString szStyleData;
-		KviFileUtils::readFile(szStylesheetFile,szStyleData);
-		szStyleData.replace("global://",m_szGlobalKvircDir);
-		szStyleData.replace("local://",m_szLocalKvircDir);
-		setStyleSheet(szStyleData);
-	}
-#endif
 
 	// create the frame window, we're almost up and running...
 	createFrame();
@@ -693,7 +655,6 @@ TQTextCodec * KviApp::defaultTextCodec()
 void KviApp::contextSensitiveHelp()
 {
 	// this stuff doesn't work with TQt 4.x
-#ifndef COMPILE_USE_QT4
 	// the F1 Key has been pressed
 	// try to pass it to the active widget or one of its parents
 	TQWidget * w = g_pApp->focusWidget();
@@ -716,7 +677,6 @@ void KviApp::contextSensitiveHelp()
 	// no way
 	// FIXME: just show up simple plain online help
 	//tqDebug("No way: found no focus widget for that...");
-#endif
 }
 
 
@@ -737,9 +697,7 @@ void KviApp::loadDefaultScript()
 #endif
 	KviKvsScript::run(cmd,g_pFrame->firstConsole());
 	// now line up the toolbars (they may get messed while loading the script)
-#ifndef COMPILE_USE_QT4
 	g_pFrame->lineUpDockWindows(); // missing on TQt 4.x
-#endif
 }
 
 // 07.01.2005 06:01: Got this curious gcc error while writing
@@ -1054,11 +1012,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 				szMsg += szLocalFileName;
 				szMsg += ")";
 			}
-#ifdef COMPILE_USE_QT4
-			notifierMessage(0,iIconId,TQt::escape(szMsg),30); 
-#else
 			notifierMessage(0,iIconId,TQStyleSheet::escape(szMsg),30);
-#endif
 		}
 		return;
 	}
@@ -2054,7 +2008,7 @@ void KviApp::timerEvent(TQTimerEvent *e)
 {
 	if(e->timerId() != m_iHeartbeatTimerId)
 	{
-		TQT_BASE_OBJECT_NAME::timerEvent(e);
+		TQObject::timerEvent(e);
 		return;
 	}
 
