@@ -39,15 +39,9 @@
 #include <tqlayout.h>
 #include <tqlabel.h>
 
-#ifndef COMPILE_USE_QT4
-	// In TQt.4 we need to use TQMimeData ?
-	#include <tqdragobject.h>
-#endif
+#include <tqdragobject.h>
 #include <tqcursor.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <tqevent.h>
-#endif
 
 // kvi_app.cpp
 extern TQPixmap * g_pUserChanStatePixmap;
@@ -352,11 +346,7 @@ static const char * g_szIconNames[KVI_NUM_SMALL_ICONS]=
 };
 
 KviIconWidget::KviIconWidget()
-#ifdef COMPILE_USE_QT4
-: TQWidget(0,"global_icon_widget" /*,WType_TopLevel | WStyle_Customize | WStyle_Title | WStyle_StaysOnTop | WStyle_DialogBorder | WStyle_SysMenu | WStyle_Minimize*/)
-#else
 : TQWidget(0,"global_icon_widget",WType_TopLevel | WStyle_Customize | WStyle_Title | WStyle_StaysOnTop | WStyle_DialogBorder | WStyle_SysMenu | WStyle_Minimize)
-#endif
 {
 	init();
 }
@@ -413,7 +403,7 @@ bool KviIconWidget::eventFilter(TQObject * o,TQEvent *e)
 {
 	if(e->type() == TQEvent::MouseButtonPress)
 	{
-		if(o->inherits(TQLABEL_OBJECT_NAME_STRING))
+		if(o->inherits("TQLabel"))
 		{
 			KviStr szName = ((TQLabel *)o)->name();
 			bool bOk;
@@ -428,11 +418,9 @@ bool KviIconWidget::eventFilter(TQObject * o,TQEvent *e)
 				if(const TQPixmap * pix = ((TQLabel *)o)->pixmap())
 				{
 // FIXME: In TQt 4.x this stuff needs to be ported to a different api.. which one ?
-#ifndef COMPILE_USE_QT4
 					TQDragObject * drobj = new TQTextDrag(o->name(),this);
 					drobj->setPixmap(*pix,((TQLabel *)o)->mapFromGlobal(TQCursor::pos()));
 					drobj->dragCopy();
-#endif
 					return true;
 				}
 			}
