@@ -175,7 +175,7 @@ void KviIrcLink::resolverTerminated()
 {
 	if(!m_pResolver)
 	{
-		debug("Oops... resoverTerminated() triggered without a resolver ?");
+		tqDebug("Oops... resoverTerminated() triggered without a resolver ?");
 		return;
 	}
 
@@ -312,7 +312,7 @@ void KviIrcLink::processData(char * buffer,int len)
 		//The m_pReadBuffer contains at max 1 irc message...
 		//that can not be longer than 510 bytes (the message is not CRLF terminated)
 		// FIXME: Is this limit *really* valid on all servers ?
-		if(m_uReadBufferLen > 510)debug("WARNING : Receiving an invalid irc message from server.");
+		if(m_uReadBufferLen > 510)tqDebug("WARNING : Receiving an invalid irc message from server.");
 	}
 	kvi_free(messageBuffer);
 }
@@ -359,7 +359,7 @@ void KviIrcLink::socketStateChange()
 					m_pConnection->linkTerminated();
 				break;
 				default: // currently can be only Idle
-					debug("Ooops... got a KviIrcSocket::Idle state change when KviIrcLink::m_eState was Idle");
+					tqDebug("Ooops... got a KviIrcSocket::Idle state change when KviIrcLink::m_eState was Idle");
 				break;
 			}
 		}
