@@ -1320,15 +1320,9 @@ namespace KviKvsCoreSimpleCommands
 			KVSCSC_PARAMETER("parameters",KVS_PT_STRINGLIST,KVS_PF_OPTIONAL,l)
 		KVSCSC_PARAMETERS_END
 
-#ifdef COMPILE_USE_QT4
-		TQProcess proc;
-		proc.start(szCommand,l);
-		// FIXME: KVSCSC_pContext->warning(__tr2qs("Failed to execute command '%Q'"),&szCommand);
-#else
 		TQProcess proc(szCommand);
 		for ( TQStringList::Iterator it = l.begin(); it != l.end(); ++it ) proc.addArgument(*it);
 		if(!proc.start())KVSCSC_pContext->warning(__tr2qs("Failed to execute command '%Q'"),&szCommand);
-#endif
 		return true;
 	}
 };
