@@ -52,7 +52,7 @@ class KVIRC_API KviKvsObject : public TQObject
 {
 	friend class KviKvsObjectController;
 	friend class KviKvsObjectClass;
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviKvsObject(KviKvsObjectClass * pClass,KviKvsObject * pParent,const TQString &szName);
