@@ -60,11 +60,7 @@
 
 #include <tqdatetime.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <TQTextDocument>
-#else
 	#include <tqstylesheet.h>
-#endif
 
 
 
@@ -1147,20 +1143,8 @@ void KviServerParser::parseCtcpRequestVersion(KviCtcpMessage *msg)
 	{
 		if(!KVI_OPTION_BOOL(KviOption_boolIgnoreCtcpVersion))
 		{
-			TQString szVersion;
-#ifdef COMPILE_USE_QT4
-	#define QT4_TAG " (QT4) "
-#else
-	#define QT4_TAG
-#endif
-
-#ifdef COMPILE_ON_WINDOWS
-			szVersion = "KVIrc " KVI_VERSION QT4_TAG " '" KVI_RELEASE_NAME "' " KVI_SOURCES_DATE " - build " KVI_BUILD_DATE;
-			szVersion.append(TQString(" - %1").arg(KviOsInfo::version()));
-#else
-			szVersion = "KVIrc " KVI_VERSION QT4_TAG " '" KVI_RELEASE_NAME "' " KVI_SOURCES_DATE " - build " KVI_BUILD_DATE " - " KVI_BUILD_FLAGS;
+			TQString szVersion = "KVIrc " KVI_VERSION " '" KVI_RELEASE_NAME "' " KVI_SOURCES_DATE " - build " KVI_BUILD_DATE " - " KVI_BUILD_FLAGS;
 			szVersion.append(TQString(" - %1 (%2)").arg(KviOsInfo::name()).arg(KviOsInfo::release()));
-#endif
 			//szVersion.append(TQString(" - QT Version: %1 - %2").arg(tqVersion()).arg(__tr2qs("http://www.kvirc.net/")));
 			if(!KVI_OPTION_STRING(KviOption_stringCtcpVersionPostfix).isEmpty())
 			{
@@ -1447,11 +1431,7 @@ void KviServerParser::parseCtcpRequestAction(KviCtcpMessage *msg)
 				TQString szMsg = "<b>";
 				szMsg += msg->pSource->nick();
 				szMsg += "</b> ";
-				#ifdef COMPILE_USE_QT4
-					szMsg += TQt::escape(szData);
-				#else
 					szMsg += TQStyleSheet::escape(szData);
-				#endif
 				//tqDebug("kvi_sp_ctcp.cpp:975 debug: %s",szMsg.data());
 				g_pApp->notifierMessage(pOut,KVI_OPTION_MSGTYPE(KVI_OUT_ACTION).pixId(),szMsg,90);
 			}
