@@ -135,22 +135,14 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 
 	// Central splitter
 	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
-	#ifdef COMPILE_USE_QT4
-		m_pSplitter->setObjectName(name);
-	#else
 		m_pSplitter->setName(name);
-	#endif
 	m_pSplitter->setOpaqueResize(false);
 	// Spitted vertially on the left
 	m_pVertSplitter = new TQSplitter(Qt::Vertical,m_pSplitter);
 	m_pVertSplitter->setOpaqueResize(false);
 	// With the IRC view over
 	m_pIrcView = new KviIrcView(m_pVertSplitter,lpFrm,this);
-	#ifdef COMPILE_USE_QT4
-		m_pIrcView->setObjectName(name);
-	#else
 		m_pIrcView->setName(name);
-	#endif
 	connect(m_pIrcView,TQT_SIGNAL(rightClicked()),this,TQT_SLOT(textViewRightClicked()));
 	// And the double view (that may be unused)
 	m_pMessageView = 0;
@@ -191,11 +183,7 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 
 	m_pHideToolsButton = new KviStyledToolButton(m_pButtonBox,"hide_container_button");
 
-#ifndef  COMPILE_USE_QT4
 	m_pHideToolsButton->setUsesBigPixmap(false);
-#else
-	m_pHideToolsButton->setAutoRaise(true);
-#endif
 	m_pHideToolsButton->setFixedWidth(10);
 
 	if(g_pIconManager->getBigIcon("kvi_horizontal_left.png"))
@@ -301,15 +289,7 @@ void KviChannel::saveProperties(KviConfig *cfg)
 	KviWindow::saveProperties(cfg);
 	cfg->writeEntry("TopSplitter",m_pTopSplitter->sizes());
 	cfg->writeEntry("Splitter",m_pSplitter->sizes());
-#ifdef COMPILE_USE_QT4
-	TQPtrList<int> tmp = m_pVertSplitter->sizes();
-	KviValueList<int> tmp2;
-	for(TQPtrList<int>::Iterator it = tmp.begin();it != tmp.end();++it)
-		tmp2.append(*it);
-	cfg->writeEntry("VertSplitter",m_pMessageView ? tmp2 : m_VertSplitterSizesList);
-#else
 	cfg->writeEntry("VertSplitter",m_pMessageView ? m_pVertSplitter->sizes() : m_VertSplitterSizesList);
-#endif
 	cfg->writeEntry("PrivateBackground",m_privateBackground);
 	cfg->writeEntry("DoubleView",m_pMessageView ? true : false);
 	if(m_pUserListView)
@@ -417,7 +397,7 @@ void KviChannel::toggleModeEditor()
 		connect(m_pModeEditor,TQT_SIGNAL(setMode(const char *)),this,TQT_SLOT(setMode(const char *)));
 		connect(m_pModeEditor,TQT_SIGNAL(done()),this,TQT_SLOT(modeSelectorDone()));
 		m_pModeEditor->show();
-		//setFocusHandlerNoClass(m_pInput,m_pModeEditor,TQLINEEDIT_OBJECT_NAME_STRING);
+		//setFocusHandlerNoClass(m_pInput,m_pModeEditor,"TQLineEdit");
 		if(!m_pModeEditorButton->isOn())m_pModeEditorButton->setOn(true);
 	}
 }
@@ -545,19 +525,11 @@ TQPixmap * KviChannel::myIconPtr()
 
 void KviChannel::resizeEvent(TQResizeEvent *e)
 {
-#ifdef COMPILE_USE_QT4
-	int hght = m_pInput->heightHint();
-	int hght2 = m_pTopicWidget->sizeHint().height();
-	m_pButtonBox->setGeometry(0,0,width(),hght2);
-	m_pSplitter->setGeometry(0,hght2,width(),height() - (hght + hght2));
-	m_pInput->setGeometry(0,height() - hght,width(),hght);
-#else
 	int hght = m_pInput->heightHint();
 	int hght2 = m_pButtonBox->sizeHint().height();
 	m_pButtonBox->setGeometry(0,0,width(),hght2);
 	m_pSplitter->setGeometry(0,hght2,width(),height() - (hght + hght2));
 	m_pInput->setGeometry(0,height() - hght,width(),hght);
-#endif
 }
 
 TQSize KviChannel::sizeHint() const
@@ -1593,7 +1565,7 @@ void KviChannel::checkChannelSync()
 
 bool KviChannel::eventFilter(TQObject * o, TQEvent * e)
 {
-	if(e->type() == TQEvent::FocusOut && TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pTopicWidget) && \
+	if(e->type() == TQEvent::FocusOut && o == m_pTopicWidget &&
 		m_pTopicWidget->isVisible())
 		m_pTopicWidget->deactivate();
 	
