@@ -90,18 +90,11 @@
 #include <tqmessagebox.h>
 #include <tqstringlist.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <tq3mimefactory.h>
-#endif
 
 #define __KVI_DEBUG__
 #include "kvi_debug.h"
 
-#ifdef COMPILE_USE_QT4
-	#include <TQTextDocument>
-#else
 	#include <tqstylesheet.h>
-#endif
 
 extern KVIRC_API KviIrcServerDataBase           * g_pIrcServerDataBase;
 extern KVIRC_API KviProxyDataBase               * g_pProxyDataBase;
@@ -139,9 +132,6 @@ KviConsole::KviConsole(KviFrame * lpFrm,int iFlags)
 	m_pAddressEdit->setInsertionPolicy(TQComboBox::NoInsertion);
 	m_pAddressEdit->setMinimumHeight(24); //icon is 16px, + margins
 	m_pButtonBox->setStretchFactor(m_pAddressEdit,1);
-#ifdef COMPILE_USE_QT4
-	m_pButtonBox->setObjectName( TQLatin1String( "kvi_window_button_box" ) );
-#endif
 	KviTalToolTip::add(m_pAddressEdit,__tr2qs("Current IRC URI"));
 	connect(m_pAddressEdit,TQT_SIGNAL(activated(const TQString & )),this,TQT_SLOT(ircUriChanged(const TQString & )));
 	connect(g_pApp,TQT_SIGNAL(recentUrlsChanged()),this,TQT_SLOT(recentUrlsChanged()));
@@ -348,11 +338,7 @@ void KviConsole::getUserTipText(const TQString &nick,KviIrcUserEntry *e,TQString
 	}
 	if(e->avatar())
 	{
-#ifdef COMPILE_USE_QT4
-		Q3MimeSourceFactory::defaultFactory()->setPixmap("ulv_avatar",*(e->avatar()->pixmap()));
-#else
 		TQMimeSourceFactory::defaultFactory()->setPixmap("ulv_avatar",*(e->avatar()->pixmap()));
-#endif
 		buffer += TQString("<tr><td><center><img src=\"ulv_avatar\" width=\"%1\"></center></td></tr>").arg(e->avatar()->pixmap()->width());
 	}
 
@@ -767,11 +753,7 @@ void KviConsole::outputPrivmsg(KviWindow *wnd,
 					TQString szMsg = "<b>&lt;";
 					szMsg += nick;
 					szMsg += "&gt;</b> ";
-					#ifdef COMPILE_USE_QT4
-						szMsg += TQt::escape(szDecodedMessage);
-					#else
 						szMsg += TQStyleSheet::escape(szDecodedMessage);
-					#endif
 					//tqDebug("kvi_console.cpp:629 debug: %s",szMsg.data());
 					g_pApp->notifierMessage(wnd,KVI_OPTION_MSGTYPE(iSaveType).pixId(),szMsg,90);
 				}
