@@ -78,11 +78,7 @@
 
 		m_pWindow = wnd;
 
-#ifdef COMPILE_USE_QT4
-		setFocusPolicy(TQ_ClickFocus);
-#else
-		setFocusPolicy(TQ_ClickFocus);
-#endif
+		setFocusPolicy(TQWidget::ClickFocus);
 
 		TQGridLayout *g = new TQGridLayout(this,10,4,2,2);
 
@@ -106,11 +102,7 @@
 
 		m_pDescriptionLabel = new TQLabel(this);
 		m_pDescriptionLabel->setFrameStyle(TQFrame::Sunken | TQFrame::StyledPanel);
-#ifdef COMPILE_USE_QT4
 		m_pDescriptionLabel->setAlignment(TQt::AlignTop | TQt::AlignLeft);
-#else
-		m_pDescriptionLabel->setAlignment(TQt::AlignTop | TQt::AlignLeft);
-#endif
 		g->addMultiCellWidget(m_pDescriptionLabel,3,3,1,3);
 
 		m_pAuthorLabel = new TQLabel(this);
