@@ -40,19 +40,8 @@
 #include <tqpainter.h>
 #include <tqstyle.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <tqevent.h>
-	#include <tq3dragobject.h>
-	
-	#define TQDragObject Q3DragObject
-	#define TQTextDrag Q3TextDrag
-	#define TQIconDrag Q3IconDrag
-	
-	#include <tqstyleoption.h>
-#else
 	#include <tqobjectlist.h>
 	#include <tqdragobject.h>
-#endif
 
 
 
@@ -67,13 +56,7 @@ KviCustomToolBarSeparator::KviCustomToolBarSeparator(KviCustomToolBar *pParent,c
 
 TQSize KviCustomToolBarSeparator::sizeHint() const
 {
-#ifdef COMPILE_USE_QT4
-	TQStyleOption opt;
-	opt.initFrom(this);
-	int extent = style()->pixelMetric(TQStyle::PM_ToolBarSeparatorExtent,&opt,this);
-#else
 	int extent = style().pixelMetric(TQStyle::PM_DockWindowSeparatorExtent,this);
-#endif
 	if(m_pToolBar->orientation() == Qt::Horizontal)return TQSize(extent,0);
 	else return TQSize(0,extent);
 }
@@ -81,15 +64,9 @@ TQSize KviCustomToolBarSeparator::sizeHint() const
 void KviCustomToolBarSeparator::paintEvent(TQPaintEvent *)
 {
 	TQPainter p(this);
-#ifdef COMPILE_USE_QT4
-	TQStyleOption opt;
-	opt.initFrom(this);
-	style()->drawPrimitive(TQStyle::PE_Q3DockWindowSeparator,&opt,&p,this);
-#else
 	TQStyle::SFlags flags = TQStyle::Style_Default;
 	if(m_pToolBar->orientation() == Qt::Horizontal)flags |= TQStyle::Style_Horizontal;
 	style().tqdrawPrimitive(TQStyle::PE_DockWindowSeparator,&p,rect(),colorGroup(),flags);
-#endif
 }
 
 
@@ -136,7 +113,7 @@ void KviCustomToolBar::paintEvent(TQPaintEvent * e)
 void KviCustomToolBar::filteredChildDestroyed()
 {
 	if(!m_pFilteredChildren)return;
-	const TQObject * o = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+	const TQObject * o = sender();
 	m_pFilteredChildren->remove((void *)o);
 }
 
@@ -170,14 +147,6 @@ void KviCustomToolBar::beginCustomize()
 	m_pFilteredChildren = new KviPointerHashTable<void *,bool>;
 	m_pFilteredChildren->setAutoDelete(true);
 	// filter the events for all the children
-#ifdef COMPILE_USE_QT4
-	TQPtrList<TQObject*> l = children();
-	for(TQPtrList<TQObject*>::Iterator it = l.begin();it != l.end();++it)
-	{
-		if((*it)->isWidgetType())
-			filterChild(*it);
-	}
-#else
 	const TQObjectList l = childrenListObject();
 	TQObjectListIterator it(l);
 	while(TQObject * o = it.current())
@@ -186,20 +155,11 @@ void KviCustomToolBar::beginCustomize()
 			filterChild(o);
 		++it;
 	}
-#endif
 }
 
 void KviCustomToolBar::endCustomize()
 {
 	// stop filtering events
-#ifdef COMPILE_USE_QT4
-	TQPtrList<TQObject*> l = children();
-	for(TQPtrList<TQObject*>::Iterator it = l.begin();it != l.end();++it)
-	{
-		if((*it)->isWidgetType())
-			unfilterChild(*it);
-	}
-#else
 	const TQObjectList l = childrenListObject();
 	TQObjectListIterator it(l);
 	while(TQObject * o = it.current())
@@ -208,7 +168,6 @@ void KviCustomToolBar::endCustomize()
 			unfilterChild(o);
 		++it;
 	}
-#endif
 	// FIXME: We SHOULD MAKE SURE that the children are re-enabled...
 	// this could be done by calling setEnabled(isEnabled()) on each action ?
 	if(m_pFilteredChildren)
@@ -272,29 +231,11 @@ void KviCustomToolBar::dragEnterEvent(TQDragEnterEvent *e)
 				e->accept(true);
 				int idx = dropIndexAt(mapFromGlobal(TQCursor::pos()),0,0);
 				m_pDraggedChild = a->addToCustomToolBar(this);
-#ifdef COMPILE_USE_QT4
-				TQWidget * pWidgetToMove = widgetAt(idx);
-				bool bDone = false;
-				TQAction * a;
-				if(pWidgetToMove)
-				{
-					a = actionForWidget(pWidgetToMove);
-					if(a)
-					{
-						bDone = true;
-						a = insertWidget(a,m_pDraggedChild);
-					}
-				}
-				if(!bDone)
-					a = addWidget(m_pDraggedChild);
-				a->setVisible(true);
-#else
 				boxLayout()->remove(m_pDraggedChild); // in case it was already added
 				boxLayout()->insertWidget(idx,m_pDraggedChild);
 #ifdef COMPILE_TDE_SUPPORT
 				// bleah ://///
 				insertWidget(-1,m_pDraggedChild->sizeHint().width(),m_pDraggedChild,idx);
-#endif
 #endif
 				TQEvent ev(TQEvent::LayoutHint);
 				TQApplication::sendEvent(this,&ev);
@@ -333,11 +274,7 @@ int KviCustomToolBar::dropIndexAt(const TQPoint &pnt,TQWidget * exclude,int * ex
 	// find the widget at the current poisition
 	// treating exclude as if it was going to be removed
 	// find also the exclude index if needed
-#ifdef COMPILE_USE_QT4
-	TQLayout * l = layout();
-#else
 	TQBoxLayout * l = boxLayout();
-#endif
 	TQLayoutItem * i = 0;
 	if(excludeIdx)*excludeIdx = -1;
 	int idx = 0;
@@ -450,24 +387,6 @@ int KviCustomToolBar::dropIndexAt(const TQPoint &pnt,TQWidget * exclude,int * ex
 
 }
 
-#ifdef COMPILE_USE_QT4
-TQWidget * KviCustomToolBar::widgetAt(int index)
-{
-	TQLayout * l = layout();
-	if(!l)
-		return NULL;
-	TQLayoutItem * it = l->itemAt(index);
-	if(!it)
-		return NULL;
-	return it->widget();
-}
-
-TQAction * KviCustomToolBar::actionForWidget(TQWidget * pWidget)
-{
-	return actionAt(pWidget->x() + 1,pWidget->y() + 1);
-}
-
-#endif
 
 void KviCustomToolBar::drag(TQWidget * child,const TQPoint &pnt)
 {
@@ -476,40 +395,11 @@ void KviCustomToolBar::drag(TQWidget * child,const TQPoint &pnt)
 	tqDebug("DROP INDEX IS %d, ME IS %d",idx,me);
 	if(idx == me)
 		return; // would move over itself
-#ifdef COMPILE_USE_QT4
-	TQWidget * pWidgetToMove = widgetAt(idx > me ? idx-1 : idx);
-	tqDebug("SEARCHING FOR WIDGET TO MOVE AT %d AND FOUND %x (ME=%x)",idx > me ? idx-1 : idx,pWidgetToMove,child);
-	if(pWidgetToMove == child)
-		return; // hmmm
-	bool bDone = false;
-	TQAction * pMyOwnAction = actionForWidget(child);
-	if(!pMyOwnAction)
-		return;
-	TQAction * a;
-	removeAction(pMyOwnAction);
-	if(pWidgetToMove)
-	{
-		a = actionForWidget(pWidgetToMove);
-		if(a)
-		{
-			tqDebug("AND GOT ACTION FOR THAT WIDGET");
-
-			bDone = true;
-			a = insertWidget(a,child);
-		}
-	} else {
-		addAction(a);
-	}
-	if(!bDone)
-		a = addWidget(child);
-	a->setVisible(true);
-#else
 	boxLayout()->remove(child);
 	boxLayout()->insertWidget(idx,child);
 #ifdef COMPILE_TDE_SUPPORT
 	// bleah ://///
 	insertWidget(-1,child->width(),child,idx);
-#endif
 #endif
 	TQEvent ev(TQEvent::LayoutHint);
 	TQApplication::sendEvent(this,&ev);
@@ -544,7 +434,7 @@ bool KviCustomToolBar::eventFilter(TQObject *o,TQEvent *e)
 				if(!(
 					o->inherits("KviTalPopupMenu") ||
 					o->inherits("TQToolBarHandle") ||
-					o->inherits(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING) ||
+					o->inherits("TQDockWindowHandle") ||
 					o->inherits("TQDockWindowResizeHandle") ||
 					o->inherits("TQToolBarExtensionWidget")
 					))
@@ -587,68 +477,33 @@ bool KviCustomToolBar::eventFilter(TQObject *o,TQEvent *e)
 			if((pnt.y() < 0) || (pnt.y() > height()) || (pnt.x() < 0) || (pnt.x() > width()))
 			{
 				// drag out!
-// FIXME: This is screwed up in TQt4.... :/
-#ifdef COMPILE_USE_QT4
-				TQDrag * d = new TQDrag(this);
-				TQMimeData * m = new TQMimeData();
-				m->setText(m_pMovedChild->name());
-				d->setMimeData(m);
-#else
 				TQDragObject * d = new TQTextDrag(m_pMovedChild->name(),this);
-#endif
 				KviAction * act = KviActionManager::instance()->getAction(m_pMovedChild->name());
 				if(act)
 				{
 					TQPixmap * pixie = act->bigIcon();
-#ifdef COMPILE_USE_QT4
-					if(pixie)
-					{
-						d->setPixmap(*pixie);
-						d->setHotSpot(TQPoint(3,3));
-					}
-#else
 					if(pixie)d->setPixmap(*pixie,TQPoint(3,3));
-#endif
 				}
 				//d->setPixmap(TQPixmap::grabWidget(m_pMovedChild),TQPoint(m_pMovedChild->width() / 2,m_pMovedChild->height() / 2));
 				// throw it somewhere else for now
 				if(m_pFilteredChildren)
 					unfilterChild(TQT_TQOBJECT(m_pMovedChild));
-#ifdef COMPILE_USE_QT4
-				TQAction * pActionForMovedChild = actionForWidget(m_pMovedChild);
-				if(pActionForMovedChild)
-					pActionForMovedChild->setVisible(false);
-				m_pMovedChild->hide();
-#else
 				m_pMovedChild->hide();
 				m_pMovedChild->reparent(g_pFrame,TQPoint(-1000,-1000),false);
-#endif
 				TQEvent ev(TQEvent::LayoutHint);
 				TQApplication::sendEvent(this,&ev);
-#ifdef COMPILE_USE_QT4
-				if(!d->exec(TQt::MoveAction) != TQt::MoveAction)
-#else
 				if(!d->dragMove())
-#endif
 				{
 					// the user has probably failed to remove the action from the toolbar
 					// flash the trashcan in the customize toolbars dialog
 					KviActionManager::instance()->emitRemoveActionsHintRequest();
 					// will filter it as ChildInserted
-#ifndef COMPILE_USE_QT4
 					m_pMovedChild->reparent(this,TQPoint(0,0),false);
-#endif
-#ifdef COMPILE_USE_QT4
-					TQAction * pActionForMovedChild = actionForWidget(m_pMovedChild);
-					if(pActionForMovedChild)
-						pActionForMovedChild->setVisible(false);
-#else
 					boxLayout()->insertWidget(0,m_pMovedChild);
 					m_pMovedChild->show();
 #ifdef COMPILE_TDE_SUPPORT
 					// bleah ://///
 					insertWidget(-1,m_pMovedChild->width(),m_pMovedChild,0);
-#endif
 #endif
 					TQEvent ev(TQEvent::LayoutHint);
 					TQApplication::sendEvent(this,&ev);
