@@ -71,21 +71,10 @@
 
 #include <tqfile.h>
 #include <tqtextstream.h>
-#ifdef COMPILE_USE_QT4
-	#include <tq3dockarea.h>
-	#define TQDockArea Q3DockArea
-#else
 	#include <tqdockarea.h>
-#endif
 
 
-#ifdef COMPILE_USE_QT4
-	#include <tqdesktopwidget.h>
-	#include <tqevent.h>
-	#include <TQShortcut>
-#else
 	#include <tqaccel.h>
-#endif
 
 #include <time.h>
 
@@ -131,16 +120,10 @@ KviFrame::KviFrame()
 
 	// This theoretically had to exists before KviMdiManager (that uses enterSdiMode)
 	m_pMenuBar   = new KviMenuBar(this,"main_menu_bar");
-#ifdef COMPILE_USE_QT4
-	setMenuWidget(m_pMenuBar);
-#endif
 
 	if(KVI_OPTION_BOOL(KviOption_boolStatusBarVisible))
 	{
 		m_pStatusBar = new KviStatusBar(this);
-#ifdef COMPILE_USE_QT4
-		setStatusBar(m_pStatusBar);
-#endif
 		// torque: moved out of status bar constructor
 		// because module init functions exectued in load()
 		// couldn't access the status bar via g_pFrame->mainStatusBar()
@@ -346,15 +329,6 @@ KviMexToolBar * KviFrame::moduleExtensionToolBar(int extensionId)
 KviAccel * KviFrame::installAccelerators(TQWidget * wnd)
 {
 	TQWidget * pParent = wnd ? (TQWidget *)wnd : (TQWidget *)this;
-#ifdef COMPILE_USE_QT4
-	new TQShortcut(TQKeySequence(TQt::Key_Left + TQt::ALT),pParent,TQT_SLOT(switchToPrevWindow()));
-	new TQShortcut(TQKeySequence(TQt::Key_Right + TQt::ALT),pParent,TQT_SLOT(switchToNextWindow()));
-	new TQShortcut(TQKeySequence(TQt::Key_Up + TQt::CTRL),pParent,TQT_SLOT(maximizeWindow()));
-	new TQShortcut(TQKeySequence(TQt::Key_Down + TQt::CTRL),pParent,TQT_SLOT(minimizeWindow()));
-	new TQShortcut(TQKeySequence(TQt::Key_Escape +TQt::CTRL),pParent,TQT_SLOT(minimizeWindow()));
-	new TQShortcut(TQKeySequence(TQt::Key_Left + TQt::ALT + TQt::SHIFT),pParent,TQT_SLOT(switchToPrevWindowInContext()));
-	new TQShortcut(TQKeySequence(TQt::Key_Right + TQt::ALT + TQt::SHIFT),pParent,TQT_SLOT(switchToNextWindowInContext()));
-#endif
 	KviAccel *ac = new KviAccel(pParent);
 
 	static int accel_table[] = {
@@ -417,7 +391,7 @@ KviAccel * KviFrame::installAccelerators(TQWidget * wnd)
 
 void KviFrame::accelActivated(int id)
 {
-	KviAccel * acc = (KviAccel *)TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+	KviAccel * acc = (KviAccel *)sender();
 
 	int keys = (int)(acc->key(id));
 	KviTaskBarItem *item = 0;
@@ -1060,13 +1034,8 @@ void KviFrame::toggleStatusBar()
 
 		m_pStatusBar = new KviStatusBar(this);
 		m_pStatusBar->load();
-#ifdef COMPILE_USE_QT4
-		setStatusBar(m_pStatusBar);
-#endif
 		m_pStatusBar->show();
-#ifndef COMPILE_USE_QT4
 		setUpLayout();
-#endif //!COMPILE_USE_QT4
 	}
 }
 
@@ -1139,7 +1108,7 @@ void KviFrame::customizeToolBars()
 
 void KviFrame::toolbarsPopupSelected(int id)
 {
-	const TQObject * o = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+	const TQObject * o = sender();
 	if(!o)return;
 	if(!o->inherits("KviTalPopupMenu"))return;
 	const KviTalPopupMenu * p = (const KviTalPopupMenu *)o;
@@ -1168,11 +1137,7 @@ bool KviFrame::focusNextPrevChild(bool next)
 	TQWidget * w = focusWidget();
 	if(w)
 	{
-#ifdef COMPILE_USE_QT4
-		if(w->focusPolicy() == TQ_StrongFocus)return false;
-#else
-		if(w->focusPolicy() == TQ_StrongFocus)return false;
-#endif
+		if(w->focusPolicy() == TQWidget::StrongFocus)return false;
 		//TQVariant v = w->property("KviProperty_FocusOwner");
 		//if(v.isValid())return false; // Do NOT change the focus widget!
 
@@ -1204,13 +1169,9 @@ void KviFrame::saveToolBarPositions()
 	TQFile f(szTemp);
 	if(f.open(IO_WriteOnly | IO_Truncate))
 	{
-#ifdef COMPILE_USE_QT4
-		f.write(saveState(1));
-#else //!COMPILE_USE_QT4
 		TQTextStream ts(&f);
 		ts << *this;
 		f.close();
-#endif //!COMPILE_USE_QT4
 	}
 }
 
@@ -1225,26 +1186,15 @@ void KviFrame::restoreToolBarPositions()
 
 	if(f.open(IO_ReadOnly))
 	{
-#ifdef COMPILE_USE_QT4
-		if(!restoreState(f.readAll(),1))
-			tqDebug("Error while restoring toolbars position");
-#else //!COMPILE_USE_QT4
 		TQTextStream ts(&f);
 		ts >> *this;
 		f.close();
-#endif //!COMPILE_USE_QT4
 	} else {
 		bNeedDefaults = true;
 	}
 
 	if(m_pTaskBar->inherits("KviTreeTaskBar"))
 	{
-#ifdef COMPILE_USE_QT4
-		// ensure that it is not too wide
-		m_pTaskBar->setMaximumWidth(600);
-		if(m_pTaskBar->width() > 600)
-			m_pTaskBar->setFixedWidth(250);
-#else //!COMPILE_USE_QT4
 		TQDockArea * a = m_pTaskBar->area();
 		if((a == topDock()) || (a == bottomDock()))
 		{
@@ -1259,7 +1209,6 @@ void KviFrame::restoreToolBarPositions()
 		// ensure that it is not too wide
 		if(m_pTaskBar->width() > 600)
 			m_pTaskBar->setFixedExtentWidth(250);
-#endif //!COMPILE_USE_QT4
 	} /*else if(m_pTaskBar->inherits("KviClassicTaskBar"))
 	{
 		TQDockArea * a = m_pTaskBar->area();
@@ -1272,10 +1221,8 @@ void KviFrame::restoreToolBarPositions()
 		}
 	}*/
 
-#ifndef COMPILE_USE_QT4
 	if(bNeedDefaults)
 		lineUpDockWindows(false);
-#endif //!COMPILE_USE_QT4
 }
 
 
@@ -1284,27 +1231,15 @@ void KviFrame::createTaskBar()
 	if(KVI_OPTION_BOOL(KviOption_boolUseTreeWindowListTaskBar))
 	{
 		m_pTaskBar = new KviTreeTaskBar();
-#ifdef COMPILE_USE_QT4
-		m_pTaskBar->setAllowedAreas(TQt::LeftDockWidgetArea | TQt::RightDockWidgetArea);
-		addDockWidget(TQt::LeftDockWidgetArea,m_pTaskBar);
-#else //!COMPILE_USE_QT4
 		setDockEnabled(m_pTaskBar,TQt::DockTop,false);
 		setDockEnabled(m_pTaskBar,TQt::DockBottom,false);
-#endif //!COMPILE_USE_QT4
 	} else {
 		m_pTaskBar = new KviClassicTaskBar();
-#ifdef COMPILE_USE_QT4
-		m_pTaskBar->setAllowedAreas(TQt::AllDockWidgetAreas);
-		addDockWidget(TQt::BottomDockWidgetArea,m_pTaskBar);
-#else //!COMPILE_USE_QT4
 		setDockEnabled(m_pTaskBar,TQt::DockTop,true);
 		setDockEnabled(m_pTaskBar,TQt::DockBottom,true);
-#endif //!COMPILE_USE_QT4
 	}
-#ifndef COMPILE_USE_QT4
 	setDockEnabled(m_pTaskBar,TQt::DockLeft,true);
 	setDockEnabled(m_pTaskBar,TQt::DockRight,true);
-#endif //!COMPILE_USE_QT4
 }
 
 void KviFrame::recreateTaskBar()
@@ -1317,9 +1252,7 @@ void KviFrame::recreateTaskBar()
 	{
 		w->destroyTaskBarItem();
 	}
-#ifndef COMPILE_USE_QT4
 	removeDockWindow(m_pTaskBar);
-#endif //!COMPILE_USE_QT4
 	delete m_pTaskBar;
 	createTaskBar();
 	for(w = m_pWinList->first();w;w = m_pWinList->next())
