@@ -71,9 +71,6 @@ public:
 	void load(const char * filename);
 };
 
-#ifdef COMPILE_USE_QT4
-	#define TQIMEvent TQInputMethodEvent
-#endif
 
 class KVIRC_API KviInputEditor : public TQFrame
 {
@@ -81,7 +78,7 @@ class KVIRC_API KviInputEditor : public TQFrame
 	//TQ_PROPERTY( int KviProperty_FocusOwner READ heightHint )
 	TQ_PROPERTY( int TransparencyCapable READ heightHint )
 
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviInputEditor(TQWidget * par,KviWindow *wnd,KviUserListView * view = 0);
@@ -210,16 +207,13 @@ protected:
 	virtual void imStartEvent(TQIMEvent *e);
 	virtual void imComposeEvent(TQIMEvent *e);
 	virtual void imEndEvent(TQIMEvent *e);
-#ifdef COMPILE_USE_QT4
-	virtual void paintEvent(TQPaintEvent *e);
-#endif
 };
 
 class KviScriptEditor;
 
 class KVIRC_API KviInput : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviInput(KviWindow *par,KviUserListView * view = 0);
