@@ -45,9 +45,6 @@
 #include <tqdrawutil.h>
 #include <tqevent.h>
 
-#ifdef COMPILE_USE_QT4
-	#include "kvi_tal_hbox.h"
-#endif
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 	#include <tqpixmap.h>
@@ -74,9 +71,6 @@ KviMdiManager::KviMdiManager(TQWidget * parent,KviFrame * pFrm,const char * name
 	m_pSdiCloseButton = 0;
 	m_pSdiRestoreButton = 0;
 	m_pSdiMinimizeButton = 0;
-#ifdef COMPILE_USE_QT4
-	m_pSdiControls = 0;
-#endif
 
 	m_pWindowPopup = new KviTalPopupMenu(this);
 	connect(m_pWindowPopup,TQT_SIGNAL(activated(int)),this,TQT_SLOT(menuActivated(int)));
@@ -84,21 +78,12 @@ KviMdiManager::KviMdiManager(TQWidget * parent,KviFrame * pFrm,const char * name
 	m_pTileMethodPopup = new KviTalPopupMenu(this);
 	connect(m_pTileMethodPopup,TQT_SIGNAL(activated(int)),this,TQT_SLOT(tileMethodMenuActivated(int)));
 
-#ifdef COMPILE_USE_QT4
-	viewport()->setAutoFillBackground(false);
-#else
 	viewport()->setBackgroundMode(TQWidget::NoBackground);
-#endif
 	setStaticBackground(true);
 	resizeContents(width(),height());
 
-#ifdef COMPILE_USE_QT4
-	setFocusPolicy(TQ_NoFocus);
-	viewport()->setFocusPolicy(TQ_NoFocus);
-#else
-	setFocusPolicy(TQ_NoFocus);
-	viewport()->setFocusPolicy(TQ_NoFocus);
-#endif
+	setFocusPolicy(TQWidget::NoFocus);
+	viewport()->setFocusPolicy(TQWidget::NoFocus);
 
 	connect(g_pApp,TQT_SIGNAL(reloadImages()),this,TQT_SLOT(reloadImages()));
 }
@@ -514,14 +499,7 @@ void KviMdiManager::updateSDIMode()
 	{
 		m_pSdiIconButton = new KviMenuBarToolButton(b,*pix,"nonne");
 		connect(m_pSdiIconButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(activeChildSystemPopup()));
-#ifdef COMPILE_USE_QT4
-		// This is an obscure, undocumented and internal function in QT4 TQMenuBar
-		// I won't be surprised if this disappears....
-		b->setCornerWidget(m_pSdiIconButton,TQt::TopLeftCorner);
-		m_pSdiIconButton->show();
-#else
 		m_iSdiIconItemId = b->insertItem(m_pSdiIconButton,-1,0);
-#endif
 		connect(m_pSdiIconButton,TQT_SIGNAL(destroyed()),this,TQT_SLOT(sdiIconButtonDestroyed()));
 	} else {
 		m_pSdiIconButton->setPixmap(*pix);
@@ -557,49 +535,25 @@ void KviMdiManager::enterSDIMode(KviMdiChild *lpC)
 
 		TQWidget * pButtonParent;
 
-#ifdef COMPILE_USE_QT4
-		m_pSdiControls = new KviTalHBox(b);
-		m_pSdiControls->setMargin(0);
-		m_pSdiControls->setSpacing(2);
-		m_pSdiControls->setAutoFillBackground(false);
-		pButtonParent = m_pSdiControls;
-#else
 		pButtonParent = b;
-#endif
 		m_pSdiMinimizeButton = new KviMenuBarToolButton(pButtonParent,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MINIMIZE)),"btnminimize");
 		connect(m_pSdiMinimizeButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(minimizeActiveChild()));
-#ifndef COMPILE_USE_QT4
 		m_iSdiMinimizeItemId = b->insertItem(m_pSdiMinimizeButton,-1,b->count());
-#endif
 		connect(m_pSdiMinimizeButton,TQT_SIGNAL(destroyed()),this,TQT_SLOT(sdiMinimizeButtonDestroyed()));
 
 		m_pSdiRestoreButton = new KviMenuBarToolButton(pButtonParent,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RESTORE)),"btnrestore");
 		connect(m_pSdiRestoreButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(restoreActiveChild()));
-#ifndef COMPILE_USE_QT4
 		m_iSdiRestoreItemId = b->insertItem(m_pSdiRestoreButton,-1,b->count());
-#endif
 		connect(m_pSdiRestoreButton,TQT_SIGNAL(destroyed()),this,TQT_SLOT(sdiRestoreButtonDestroyed()));
 
 		m_pSdiCloseButton = new KviMenuBarToolButton(pButtonParent,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CLOSE)),"btnclose");
 		connect(m_pSdiCloseButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(closeActiveChild()));
-#ifndef COMPILE_USE_QT4
 		m_iSdiCloseItemId = b->insertItem(m_pSdiCloseButton,-1,b->count());
-#endif
 		connect(m_pSdiCloseButton,TQT_SIGNAL(destroyed()),this,TQT_SLOT(sdiCloseButtonDestroyed()));
 
-#ifdef COMPILE_USE_QT4
-		// This is an obscure, undocumented and internal function in QT4 TQMenuBar
-		// I won't be surprised if this disappears....
-		b->setCornerWidget(m_pSdiControls,TQt::TopRightCorner);
-		// The show below SHOULD force a re-layout of the menubar..
-		// but it doesn't work when the KviFrame is still hidden (at startup)
-		// We handle this BUG in showEvent()
-		m_pSdiControls->show();
-#else
 		m_pSdiRestoreButton->show();
 		m_pSdiMinimizeButton->show();
 		m_pSdiCloseButton->show();
-#endif
 		emit enteredSdiMode();
 
 		setVScrollBarMode(KviTalScrollView::AlwaysOff);
@@ -610,19 +564,6 @@ void KviMdiManager::enterSDIMode(KviMdiChild *lpC)
 }
 void KviMdiManager::relayoutMenuButtons()
 {
-#ifdef COMPILE_USE_QT4
-	// force a re-layout of the menubar in TQt4 (see the note in enterSDIMode())
-	// by resetting the corner widget
-	if(m_pSdiControls)
-	{
-		m_pFrm->mainMenuBar()->setCornerWidget(0,TQt::TopRightCorner);
-		m_pFrm->mainMenuBar()->setCornerWidget(m_pSdiControls,TQt::TopRightCorner);
-	}
-	// also force an activation of the top MdiChild since it probably didn't get it yet
-	KviMdiChild * c = topChild();
-	if(c)
-		c->activate(false);
-#endif
 }
 
 
@@ -654,24 +595,10 @@ void KviMdiManager::leaveSDIMode()
 {
 	__range_valid(m_pSdiCloseButton);
 
-#ifdef COMPILE_USE_QT4
-	if(m_pSdiControls)
-	{
-		delete m_pSdiControls;
-		m_pSdiControls = 0;
-	}
-	if(m_pSdiIconButton)
-	{
-		m_pSdiIconButton->hide(); // this will force a TQMenuBar relayout
-		delete m_pSdiIconButton;
-		m_pSdiIconButton = 0;
-	}
-#else
 	if(m_iSdiIconItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiIconItemId);
 	if(m_iSdiCloseItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiCloseItemId);
 	if(m_iSdiRestoreItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiRestoreItemId);
 	if(m_iSdiMinimizeItemId != 0)m_pFrm->mainMenuBar()->removeItem(m_iSdiMinimizeItemId);
-#endif
 
 	setVScrollBarMode(KviTalScrollView::Auto);
 	setHScrollBarMode(KviTalScrollView::Auto);
