@@ -68,18 +68,10 @@ KviModeEditor::KviModeEditor(TQWidget * par,KviWindowToolPageButton* button,cons
 	
 	TQGridLayout *pMasterLayout = new TQGridLayout(this,2,1,2,2);
 
-#ifdef COMPILE_USE_QT4
-	setFocusPolicy(TQ_ClickFocus);
-#else
-	setFocusPolicy(TQ_ClickFocus);
-#endif
+	setFocusPolicy(TQWidget::ClickFocus);
 	
 	KviTalScrollView *pScrollView = new KviTalScrollView(this);
-#ifdef COMPILE_USE_QT4
-	pScrollView->viewport()->setBackgroundRole(TQPalette::Background);
-#else
 	pScrollView->viewport()->setBackgroundMode(TQWidget::PaletteBackground);
-#endif
 	
 	pMasterLayout->addWidget(pScrollView,0,0);
 
