@@ -73,11 +73,7 @@ void KviOptionsWidget::mergeTip(TQWidget * w,const TQString &tip)
 	static TQString begin = "<table width=\"100%\" align=\"center\"><tr><td bgcolor=\"#fefef0\">";
 	static TQString mid = "</td></tr><tr><td>";
 	static TQString end = "</td></tr></table>";
-#ifdef COMPILE_USE_QT4
-	TQString s = w->toolTip();
-#else
 	TQString s = KviTalToolTip::textFor(w);
-#endif
 	if(s.isEmpty())KviTalToolTip::add(w,tip);
 	else {
 		TQString tmp = begin;
@@ -628,9 +624,6 @@ void KviOptionsWidget::addRowSpacer(int x1,int y1,int x2,int y2)
 TQLabel * KviOptionsWidget::addLabel(int x1,int y1,int x2,int y2,const TQString & text,bool bEnabled)
 {
 	TQLabel * l = new TQLabel(text,this);
-#ifdef COMPILE_USE_QT4
-	l->setWordWrap(true);
-#endif
 	l->setEnabled(bEnabled);
 	addWidgetToLayout(l,x1,y1,x2,y2);
 	return l;
@@ -639,9 +632,6 @@ TQLabel * KviOptionsWidget::addLabel(int x1,int y1,int x2,int y2,const TQString
 TQLabel * KviOptionsWidget::addLabel(TQWidget * pParent,const TQString & text,bool bEnabled)
 {
 	TQLabel * l = new TQLabel(text,pParent);
-#ifdef COMPILE_USE_QT4
-	l->setWordWrap(true);
-#endif
 	l->setEnabled(bEnabled);
 	return l;
 }
@@ -662,11 +652,7 @@ TQFrame * KviOptionsWidget::addSeparator(int x1,int y1,int x2,int y2)
 	return f;
 }
 
-#ifdef COMPILE_USE_QT4
-KviTalGroupBox * KviOptionsWidget::addGroupBox(int x1,int y1,int x2,int y2,int nStrips,Qt::Orientation o,const TQString &txt,bool bEnabled)
-#else
 KviTalGroupBox * KviOptionsWidget::addGroupBox(int x1,int y1,int x2,int y2,int nStrips,KviTalGroupBox::Orientation o,const TQString &txt,bool bEnabled)
-#endif
 {
 	KviTalGroupBox * g = new KviTalGroupBox(nStrips,o,txt,this);
 	g->setEnabled(bEnabled);
