@@ -85,11 +85,7 @@ KviQuery::KviQuery(KviFrame * lpFrm,KviConsole * lpConsole,const TQString &nick)
 
 	createTextEncodingButton(m_pButtonGrid);
 
-#ifdef COMPILE_USE_QT4
 	m_pSplitter = new TQSplitter(Qt::Horizontal,this,"main_splitter");
-#else
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this,"main_splitter");
-#endif
 	m_pIrcView = new KviIrcView(m_pSplitter,lpFrm,this);
 	connect(m_pIrcView,TQT_SIGNAL(rightClicked()),this,TQT_SLOT(textViewRightClicked()));
 	//m_pEditorsContainer= new KviToolWindowsContainer(m_pSplitter);
