@@ -625,11 +625,7 @@ KviMircTextColorSelector::KviMircTextColorSelector(TQWidget * par,const TQString
 	{
 		TQPixmap tmp(120,16);
 		tmp.fill(KVI_OPTION_MIRCCOLOR(i));
-#ifdef COMPILE_USE_QT4
-		int id = m_pForePopup->insertItem(tmp,TQString("x"));
-#else
 		int id = m_pForePopup->insertItem(tmp);
-#endif
 		m_pForePopup->setItemParameter(id,i);
 	}
 	m_pContextPopup->insertItem(__tr2qs("Foreground"),m_pForePopup);
@@ -642,11 +638,7 @@ KviMircTextColorSelector::KviMircTextColorSelector(TQWidget * par,const TQString
 	{
 		TQPixmap tmp(120,16);
 		tmp.fill(KVI_OPTION_MIRCCOLOR(i));
-#ifdef COMPILE_USE_QT4
-		int id = m_pForePopup->insertItem(tmp,TQString("x"));
-#else
 		int id = m_pBackPopup->insertItem(tmp);
-#endif
 		m_pBackPopup->setItemParameter(id,i);
 	}
 	m_pContextPopup->insertItem(__tr2qs("Background"),m_pBackPopup);
