@@ -27,7 +27,6 @@
 
 #include "kvi_styled_controls.h"
 
-#ifndef COMPILE_USE_QT4
 
 #include "kvi_iconmanager.h"
 #include "kvi_app.h"
@@ -370,4 +369,3 @@ void KviStyledToolButton::resizeEvent ( TQResizeEvent * e)
 
 #include "kvi_styled_controls.moc"
 
-#endif
