@@ -74,39 +74,11 @@ public:
 // This is the basic interface that all the external classes should see
 //
 
-// Please note that TQt3 moc skips the  *_SKIP_BEGIN -> *_SKIP_END blocks
-// while the TQt4 moc skips the Q_MOC_RUN ifdef block.. so...
-
-// TQt4 version
-
-// If you get failures (undefined references) in some non-autotools based
-// build system that uses TQt4 then you must add the -DCOMPILE_USE_QT4
-// commandline parameter to moc (at leat) when parsing this file.
-
-// MOC_SKIP_BEGIN
-#ifdef COMPILE_USE_QT4
-
-#include <TQDockWidget>
-
-class KVIRC_API KviTaskBarBase : public TQDockWidget
-{
-	Q_OBJECT
-  
-#endif //COMPILE_USE_QT4
-// MOC_SKIP_END
-
-// TQt3 version
-#ifndef Q_MOC_RUN
-#ifndef COMPILE_USE_QT4
-
 #include "kvi_toolbar.h"
 
 class KVIRC_API KviTaskBarBase : public KviToolBar
 {
-	Q_OBJECT
-  
-#endif
-#endif
+	TQ_OBJECT
 
 public:
 	KviTaskBarBase();
@@ -143,7 +115,7 @@ class KviClassicTaskBar;
 class KVIRC_API KviTaskBarButton : public TQPushButton , KviTaskBarItem
 {
 	friend class KviClassicTaskBar;
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTaskBarButton(TQWidget * par,KviWindow * wnd,const char * name);
@@ -155,9 +127,6 @@ protected:
 	virtual void mousePressEvent(TQMouseEvent *e);
 	virtual void contextMenuEvent(TQContextMenuEvent *e);
 	virtual void drawButtonLabel(TQPainter *p);
-#ifdef COMPILE_USE_QT4
-	virtual void paintEvent(TQPaintEvent * e);
-#endif
 public:
 	virtual bool active(){ return m_bActive; };
 	virtual void highlight(int iLevel = 1);
@@ -173,7 +142,7 @@ protected slots:
 
 class KVIRC_API KviClassicTaskBar : public KviTaskBarBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviClassicTaskBar();
@@ -227,11 +196,7 @@ protected:
 public:
 	virtual TQString key(int column,bool) const;
 	virtual void paintCell(TQPainter *p,const TQColorGroup &cg,int column,int width,int alignment);
-#ifdef COMPILE_USE_QT4
-	virtual void paintBranches(TQPainter *p,const TQColorGroup &cg,int w,int y,int h);
-#else
 	virtual void paintBranches(TQPainter *p,const TQColorGroup &cg,int w,int y,int h,GUIStyle s);
-#endif
 	virtual void captionChanged();
 	virtual void highlight(int iLevel = 1);
 	virtual void unhighlight();
@@ -248,7 +213,7 @@ protected:
 
 class KviTreeTaskBarItemInternal : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTreeTaskBarItemInternal(KviTreeTaskBarItem* pItem):m_pItem(pItem) {};
@@ -262,7 +227,7 @@ public slots:
 class KVIRC_API KviTreeTaskBarListView : public KviTalListView
 {
 	friend class KviTreeTaskBarItem;
-	Q_OBJECT
+	TQ_OBJECT
   
 	KviTreeTaskBarItem* m_pPrevItem;
 public:
@@ -285,7 +250,7 @@ public slots:
 
 class KVIRC_API KviTreeTaskBar : public KviTaskBarBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTreeTaskBar();
