@@ -89,17 +89,9 @@ KviTopicWidget::KviTopicWidget(TQWidget * par,const char * name)
 	m_pContextPopup = 0;
 	m_iCursorPosition = 0;
 	m_pInput = 0;
-#ifdef COMPILE_USE_QT4
-	setAutoFillBackground(false);
-#else
 	setBackgroundMode(TQWidget::NoBackground);
-#endif
 	reset();
-#ifdef COMPILE_USE_QT4
-	m_pCompletionBox=new KviTalListBox(this,TQt::Popup);
-#else
 	m_pCompletionBox=new KviTalListBox(this,TQt::WType_Popup);
-#endif
 	m_pCompletionBox->setFont( font() );
 	m_pCompletionBox->setPalette( palette() );
 //	m_pCompletionBox->setVScrollBarMode( KviTalListBox::AlwaysOff );
@@ -411,14 +403,6 @@ void KviTopicWidget::paintColoredText(TQPainter *p, TQString text,const TQColorG
 	}
 }
 
-#ifdef COMPILE_USE_QT4
-void KviTopicWidget::paintEvent(TQPaintEvent * e)
-{
-	TQPainter pa(this);
-	drawFrame(&pa);
-	drawContents(&pa);
-}
-#endif
 
 void KviTopicWidget::drawContents(TQPainter *p)
 {
@@ -639,17 +623,17 @@ bool KviTopicWidget::eventFilter(TQObject *object,TQEvent *e)
 {
 	if ( !e )
 		return TRUE;
-	if(TQT_BASE_OBJECT(object)==TQT_BASE_OBJECT(m_pCompletionBox))
+	if(object==m_pCompletionBox)
 	{
 		switch( e->type() ) {
 		case TQEvent::MouseButtonPress:
-			if ( TQT_TQRECT_OBJECT(m_pCompletionBox->rect()).contains( ((TQMouseEvent*)e)->pos() ) ) {
+			if ( m_pCompletionBox->rect().contains( ((TQMouseEvent*)e)->pos() ) ) {
 				complete(m_pCompletionBox->index(m_pCompletionBox->itemAt(((TQMouseEvent*)e)->pos())));
 				return TRUE;
 			}
 			break;
 		case TQEvent::MouseButtonRelease:
-			if ( TQT_TQRECT_OBJECT(m_pCompletionBox->rect()).contains( ((TQMouseEvent*)e)->pos() ) ) {
+			if ( m_pCompletionBox->rect().contains( ((TQMouseEvent*)e)->pos() ) ) {
 				TQMouseEvent tmp( TQEvent::MouseButtonDblClick,
 						((TQMouseEvent*)e)->pos(), ((TQMouseEvent*)e)->button(), ((TQMouseEvent*)e)->state() ) ;
 				// will hide popup
@@ -745,7 +729,7 @@ void KviTopicWidget::deactivate()
 	w = parent();
 	if(w)
 	{
-		if(w->inherits(TQWIDGET_OBJECT_NAME_STRING))
+		if(w->inherits("TQWidget"))
 			((TQWidget *)w)->setFocus();
 	}
 }
