@@ -54,11 +54,7 @@
 #include <tqcheckbox.h>
 #include <tqtooltip.h>
 #include <tqpainter.h>
-#ifdef COMPILE_USE_QT4
-	#include <tq3header.h>
-#else
 	#include <tqheader.h>
-#endif
 #include <tqtabwidget.h>
 #include <kvi_tal_groupbox.h>
 #include "kvi_valuelist.h"
@@ -654,13 +650,7 @@ KviActionEditor::KviActionEditor(TQWidget * par)
 	
 	TQGridLayout * l = new TQGridLayout(this,1,1,2,2);
 
-#ifdef COMPILE_USE_QT4
 	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
-	m_pSplitter->setOpaqueResize(false);
-
-#else
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
-#endif
 
 	l->addWidget(m_pSplitter,0,0);
 	
@@ -669,11 +659,7 @@ KviActionEditor::KviActionEditor(TQWidget * par)
 	m_pListView = new KviActionEditorListView(box);
 	//m_pListView->setMultiSelection(false);
 	m_pListView->setShowSortIndicator(true);
-#ifdef COMPILE_USE_QT4
-	m_pListView->setFocusPolicy(TQ_StrongFocus);
-#else
-	m_pListView->setFocusPolicy(TQ_StrongFocus);
-#endif
+	m_pListView->setFocusPolicy(TQWidget::StrongFocus);
 	connect(m_pListView,TQT_SIGNAL(currentChanged(KviTalListViewItem *)),this,TQT_SLOT(currentChanged(KviTalListViewItem *)));
 
 
