@@ -210,12 +210,7 @@ KviAliasEditor::KviAliasEditor(TQWidget * par)
 
 	TQGridLayout * l = new TQGridLayout(this,1,1,2,2);
 
-#ifdef COMPILE_USE_QT4
 	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
-	m_pSplitter->setOpaqueResize(false);
-#else
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
-#endif
 
 	l->addWidget(m_pSplitter,0,0);
 	
