@@ -29,7 +29,7 @@
 
 class KviClockDisplay : public KviIrcToolBarGraphicalApplet
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviClockDisplay(KviIrcToolBarAppletContainer * pContainer);
