@@ -29,13 +29,7 @@
 #include <tqlayout.h>
 #include "kvi_tal_hbox.h"
 #include <tqlineedit.h>
-#ifdef COMPILE_USE_QT4
-	#include <tq3multilineedit.h>
-	#define TQMultiLineEdit Q3MultiLineEdit
-	#include <tqdesktopwidget.h>
-#else
 	#include <tqmultilineedit.h>
-#endif
 #include <tqevent.h>
 #include <tqlabel.h>
 #include <tqpushbutton.h>
@@ -74,9 +68,7 @@ KviKvsCallbackMessageBox::KviKvsCallbackMessageBox(
 	KviKvsCallbackObject("dialog.message",pWindow,szCode,pMagicParams,0)
 {
 	g_pDialogModuleDialogList->append(this);
-#ifndef COMPILE_USE_QT4
 	setIcon(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)));
-#endif
 
 	TQPixmap * pix = g_pIconManager->getImage(szIcon);
 
