@@ -86,11 +86,7 @@ KviChannelListViewItem::~KviChannelListViewItem()
 {
 	delete m_pData;
 }
-#ifdef COMPILE_USE_QT4
-int KviChannelListViewItem::width ( const TQFontMetrics & fm, const KviTalListView * lv, int column ) const
-#else
 int KviChannelListViewItem::width ( const TQFontMetrics & fm, const TQListView * lv, int column ) const
-#endif
 {
 	tqDebug("width request");
 	TQString szText;
@@ -123,14 +119,9 @@ void KviChannelListViewItem::paintCell(TQPainter * p,const TQColorGroup &cg,int
 	int marg = lv->itemMargin();
 	int r = marg;
 
-#ifdef COMPILE_USE_QT4
-
-	p->fillRect( 0, 0, width, height(), cg.brush(lv->viewport()->backgroundRole()) );
-#else
 	const TQColorGroup::ColorRole crole = TQPalette::backgroundRoleFromMode(lv->viewport()->backgroundMode());
 	
 	p->fillRect( 0, 0, width, height(), cg.brush( crole ) );
-#endif
 
 	if ( isSelected() &&
 		(column == 0 || lv->allColumnsShowFocus()) ) {
