@@ -37,9 +37,6 @@ int IdlePlatform::secondsIdle() { return 0; }
 #include<X11/Xutil.h>
 #include<X11/extensions/scrnsaver.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <tqdesktopwidget.h>
-#endif
 
 static XErrorHandler old_handler = 0;
 extern "C" int xerrhandler(Display* dpy, XErrorEvent* err)
@@ -90,19 +87,12 @@ bool IdlePlatform::init()
 	return false;
 }
 
-#ifdef COMPILE_USE_QT4
-	#include <tqx11info_x11.h>
-#endif
 
 int IdlePlatform::secondsIdle()
 {
 	if(!d->ss_info)
 		return 0;
-#ifdef COMPILE_USE_QT4
-	if(!XScreenSaverQueryInfo(TQT_TQPAINTDEVICE(TQApplication::desktop()->screen())->x11Display(), QX11Info::appRootWindow(), d->ss_info))
-#else
 	if(!XScreenSaverQueryInfo(TQT_TQPAINTDEVICE(TQApplication::desktop()->screen())->x11Display(), tqt_xrootwin(), d->ss_info))
-#endif
 		return 0;
 	return d->ss_info->idle / 1000;
 }
