@@ -26,12 +26,7 @@
 
 
 #include "kvi_tal_listview.h"
-#ifdef COMPILE_USE_QT4
-#include <tq3header.h>
-#include <tqevent.h>
-#else
 #include <tqheader.h>
-#endif
 #include "class_listview.h"
 #include "kvi_error.h"
 #include "kvi_debug.h"
