@@ -28,17 +28,6 @@
 #include "kvi_locale.h"
 #include "kvi_malloc.h"
 #include <tqfile.h>
-#ifdef COMPILE_USE_QT4
-	#include <tq3multilineedit.h>
-#include <TQTextStream>
-
-#include <tq3stylesheet.h>
-#define KviTalMultiLineEdit Q3MultiLineEdit
-#define TQTEXTEDIT_AUTO_ALL Q3TextEdit::AutoAll
-#define TQTEXTEDIT_AUTO_NONE Q3TextEdit::AutoNone
-#define TQTEXTEDIT_AUTO_BULLET_LIST Q3TextEdit::AutoBulletList
-
-#else
 	#include <tqtextstream.h>
 
 	#include <tqmultilineedit.h>
@@ -47,7 +36,6 @@
 	#define TQTEXTEDIT_AUTO_NONE TQTextEdit::AutoNone
 	#define TQTEXTEDIT_AUTO_BULLET_LIST TQTextEdit::AutoBulletList
 
-#endif
 
 
 #include "class_multilineedit.h"
@@ -1076,13 +1064,8 @@ bool KviKvsObject_mledit::functionloadFile(KviKvsObjectFunctionCall *c)
 
 	TQTextStream ts( &file );
     TQString txt = ts.read();
-#ifdef COMPILE_USE_QT4
-	if ( !Q3StyleSheet::mightBeRichText( txt ) )
-	txt = Q3StyleSheet::convertFromPlainText( txt, Q3StyleSheetItem::WhiteSpacePre );
-#else
 	if ( !TQStyleSheet::mightBeRichText( txt ) )
 	txt = TQStyleSheet::convertFromPlainText( txt, TQStyleSheetItem::WhiteSpacePre );
-#endif
 	((KviTalMultiLineEdit *)widget())->setText( txt );
 
 	file.close();
