@@ -216,11 +216,7 @@ bool KviKvsObject_tabwidget::functionaddTab(KviKvsObjectFunctionCall *c)
 	TQPixmap * pix = g_pIconManager->getImage(szIcon);
 
 	if(pix){
-#ifdef COMPILE_USE_QT4
-		((TQTabWidget *)widget())->addTab(((TQWidget *)(ob->object())),TQIconSet(*pix),szLabel);
-#else
 		((TQTabWidget *)widget())->addTab(((TQWidget *)(ob->object())),TQIconSet(*pix,TQIconSet::Small),szLabel);
-#endif	
 	}
 	else((TQTabWidget *)widget())->addTab(((TQWidget *)(ob->object())),szLabel);	
 	return true;
@@ -257,11 +253,7 @@ bool KviKvsObject_tabwidget::functioninsertTab(KviKvsObjectFunctionCall *c)
 	}
 	TQPixmap * pix = g_pIconManager->getImage(szIcon);
 	if(pix){
-		#ifdef COMPILE_USE_QT4
-			((TQTabWidget *)widget())->insertTab( ((TQWidget *)(ob->object())),TQIconSet(*pix),szLabel,uIndex);
-		#else
 			((TQTabWidget *)widget())->insertTab(((TQWidget *)(ob->object())),TQIconSet(*pix,TQIconSet::Small),szLabel,uIndex);
-		#endif
 	}
 	else ((TQTabWidget *)widget())->insertTab(((TQWidget *)(ob->object())),szLabel,uIndex);	
 	return true;
@@ -499,11 +491,7 @@ bool KviKvsObject_tabwidget::functionchangeTab(KviKvsObjectFunctionCall *c)
 	}
 	TQPixmap * pix = g_pIconManager->getImage(szIcon);
 	if(pix){
-		#ifdef COMPILE_USE_QT4
-			((TQTabWidget *)widget())->changeTab(((TQWidget *)(ob->object())),TQIconSet(*pix),szLabel);
-		#else
 			((TQTabWidget *)widget())->changeTab(((TQWidget *)(ob->object())),TQIconSet(*pix,TQIconSet::Small),szLabel);
-		#endif
 	}
 	else ((TQTabWidget *)widget())->changeTab(((TQWidget *)(ob->object())),szLabel);	
 	return true;
