@@ -31,12 +31,7 @@
 
 #include "kvi_window.h"
 #include "kvi_kvs_script.h"
-#ifdef COMPILE_USE_QT4
-#include <TQMouseEvent>
 #define TQT_LEFT_BUTTON Qt::LeftButton
-#else
-#define TQT_LEFT_BUTTON Qt::LeftButton
-#endif
 //#warning "Functions to change colors for different states"
 //#warning "$setUnderline(), $underline()"
 
