@@ -30,10 +30,8 @@
 
 #include "class_widget.h"
 #include <tqwidget.h>
-#ifndef COMPILE_USE_QT4
-	#include <tqobjectlist.h>
-	#include <tqwidgetlist.h>
-#endif
+#include <tqobjectlist.h>
+#include <tqwidgetlist.h>
 #include "kvi_app.h"
 #include "kvi_frame.h"
 
@@ -182,28 +180,6 @@ bool KviKvsObject_wrapper::init(KviKvsRunTimeContext * pContext,KviKvsVariantLis
 }
 TQWidget *KviKvsObject_wrapper::findTopLevelWidgetToWrap(const TQString szClass, const TQString szName)
 {
-#ifdef COMPILE_USE_QT4
-	TQWidgetList list = g_pApp->topLevelWidgets();
-	if( !list.count() ) return 0;
-	for(int idx=0;idx<list.count();idx++)
-	{
-		bool bNameMatch  = false;
-		bool bClassMatch = false;
-		if( !szName.isEmpty() )
-			bNameMatch = KviTQString::equalCI(list.at(idx)->name(), szName);
-		else
-			bNameMatch = true;
-		if( !szClass.isEmpty())
-			bClassMatch = KviTQString::equalCI(list.at(idx)->className(), szClass);
-		else
-			bClassMatch = true;
-		if( bNameMatch && bClassMatch ) {
-			TQWidget *w = list.at(idx);
-			return w;
-		}
-	}
-	return 0;
-#else
 	
 	TQWidgetList *list = g_pApp->topLevelWidgets();
 	if( !list ) return 0;
@@ -230,24 +206,10 @@ TQWidget *KviKvsObject_wrapper::findTopLevelWidgetToWrap(const TQString szClass,
 	delete list;
 
 	return 0;
-#endif
 }
 
 TQWidget *KviKvsObject_wrapper::findWidgetToWrap(const char *szClass, const char *szName, TQWidget *childOf)
 {
-#ifdef COMPILE_USE_QT4
-	TQObjectList list = childOf->queryList(szClass ? szClass : 0, szName ? szName : 0, false, true);
-	if( !list.count() ) return 0;
-	for(int idx=0;idx<list.count();idx++)
-	{
-		if( list.at(idx)->isWidgetType() ) {
-			TQWidget *w = (TQWidget *)list.at(idx);
-			return w;
-		}
-		
-	}
-	return 0;
-#else
 
 	TQObjectList *list = childOf->queryList(szClass ? szClass : 0, szName ? szName : 0, false, true);
 	if( !list ) return 0;
@@ -263,7 +225,6 @@ TQWidget *KviKvsObject_wrapper::findWidgetToWrap(const char *szClass, const char
 	}
 	delete list;
 	return 0;
-#endif
 }
 
 #include "m_class_wrapper.moc"
