@@ -41,12 +41,8 @@
 #include <tqpushbutton.h>
 #include "kvi_tal_tooltip.h"
 
-#ifdef COMPILE_USE_QT4
-	#include <tq3header.h>
-#else
-	#include <tqheader.h>
-	#include <tqobjectlist.h>
-#endif
+#include <tqheader.h>
+#include <tqobjectlist.h>
 #include "kvi_tal_popupmenu.h"
 #include <tqtoolbutton.h>
 #include <tqcheckbox.h>
@@ -66,9 +62,6 @@ KviGeneralOptionsFrontWidget::KviGeneralOptionsFrontWidget(TQWidget *parent,cons
 {
 	createLayout(1,1);
 	TQLabel * l = new TQLabel(szText,this);
-#ifdef COMPILE_USE_QT4
-	l->setWordWrap(true);
-#endif
 	l->setAlignment(TQt::AlignTop);
 	layout()->addWidget(l,0,0);
 }
@@ -308,7 +301,7 @@ void KviOptionsDialog::searchLineEditTextChanged(const TQString &)
 
 bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const TQStringList &lKeywords)
 {
-	//debug("recursive search:");
+	//tqDebug("recursive search:");
 	if(!pItem)return false;
 
 	if(!pItem->m_pOptionsWidget)
@@ -323,43 +316,26 @@ bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const TQSt
 	TQTabWidget * pTabWidgetToMark = 0;
 	
 	TQObject * o;
-#ifdef COMPILE_USE_QT4
-	TQObjectList ol = pItem->m_pOptionsWidget->queryList();
-	if(ol.count() > 0)
-	{
-		for(TQObjectList::Iterator it = ol.begin();it != ol.end();++it)
-		{
-			o = *it;
-#else
 	TQObjectList * ol = pItem->m_pOptionsWidget->queryList();
 	if(ol)
 	{
 		TQObjectListIt it(*ol);
 		while((o = it.current())/* && (!bFoundSomethingHere)*/)
 		{
-#endif
 			TQString szText;
-			if(o->inherits(TQLABEL_OBJECT_NAME_STRING))szText = ((TQLabel *)o)->text();
-			else if(o->inherits(TQCHECKBOX_OBJECT_NAME_STRING))szText = ((TQCheckBox *)o)->text();
+			if(o->inherits("TQLabel"))szText = ((TQLabel *)o)->text();
+			else if(o->inherits("TQCheckBox"))szText = ((TQCheckBox *)o)->text();
 			else if(o->inherits("KviTalGroupBox"))szText = ((KviTalGroupBox *)o)->title();
 #ifdef COMPILE_INFO_TIPS
-			if(o->inherits(TQWIDGET_OBJECT_NAME_STRING))
-#ifdef COMPILE_USE_QT4
-				szText.append(((TQWidget *)o)->toolTip());
-#else
+			if(o->inherits("TQWidget"))
 				szText.append(TQToolTip::textFor((TQWidget*)o));
-#endif
 #endif
 			if(!szText.isEmpty())
 			{
 				bool bOk = true;
 				for(int j=0;j<lKeywords.count();j++)
 				{
-#ifdef COMPILE_USE_QT4
-					if(szText.find(lKeywords.at(j),0,false) == -1)
-#else
 					if(szText.find(*(lKeywords.at(j)),0,false) == -1)
-#endif
 					{
 						bOk = false;
 						break;
@@ -370,7 +346,7 @@ bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const TQSt
 					bFoundSomethingHere = true;
 				}
 				
-				if(o->inherits(TQWIDGET_OBJECT_NAME_STRING))
+				if(o->inherits("TQWidget"))
 				{
 					TQWidget* pWidget=(TQWidget*)o;
 					TQFont font = pWidget->font();
@@ -382,7 +358,7 @@ bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const TQSt
 					TQObject * pParent = pWidget->parent();
 					while(pParent)
 					{
-						if(pParent->inherits(TQTABWIDGET_OBJECT_NAME_STRING))
+						if(pParent->inherits("TQTabWidget"))
 						{
 							pTabWidgetToMark = (TQTabWidget *)pParent;
 							break;
@@ -414,13 +390,9 @@ bool KviOptionsDialog::recursiveSearch(KviOptionsListViewItem * pItem,const TQSt
 				}
 			}
 
-#ifndef COMPILE_USE_QT4
 			++it;
-#endif
 		}
-#ifndef COMPILE_USE_QT4
 		delete ol;
-#endif
 	}
 
 	if(pTabWidgetToMark)
