@@ -301,7 +301,7 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(TQWidget * pare
 				"forcibly inserted between each sent/received data packet.</center>","options"));
 #endif // COMPILE_INFO_TIPS
 
-	u = addUIntSelector(hb,__tr2qs_ctx("","options"),KviOption_uintDccSendIdleStepInMSec,1,65536,30,KVI_OPTION_BOOL(KviOption_boolDccSendForceIdleStep));
+	u = addUIntSelector(hb,"",KviOption_uintDccSendIdleStepInMSec,1,65536,30,KVI_OPTION_BOOL(KviOption_boolDccSendForceIdleStep));
 	connect(b,TQT_SIGNAL(toggled(bool)),u,TQT_SLOT(setEnabled(bool)));
 	u->setSuffix(__tr2qs_ctx(" msec","options"));
 	
