@@ -297,17 +297,9 @@ void KviMessageListViewItem::paintCell(TQPainter * p,const TQColorGroup &,int,in
 	p->drawText(24,listView()->itemMargin(),w - 24,height() - (listView()->itemMargin() * 2),TQt::AlignLeft | TQt::AlignVCenter,txt);
 	if(isSelected())
 	{
-#ifdef COMPILE_USE_QT4
-		TQPen pen(KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
-		pen.setStyle(TQt::DashLine);
-		p->setPen( pen);
-		p->drawRect(0,0,w,height());
-		p->drawRect(1,1,w - 2,height() - 2);
-#else
 	
 		p->drawWinFocusRect(0,0,w,height(),KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
 		p->drawWinFocusRect(1,1,w - 2,height() - 2,KVI_OPTION_COLOR(KviOption_colorIrcViewBackground));
-#endif
 	}
 }
 
@@ -340,18 +332,9 @@ void KviMessageColorListBoxItem::paint(TQPainter * p)
 	}
 	if(isSelected())
 	{
-#ifdef COMPILE_USE_QT4
-	TQPen pen(clr);
-	pen.setStyle(TQt::DashLine);
-	p->setPen( pen);
-	p->drawRect(0,0,width(lb),height(lb));
-	p->drawRect(1,1,width(lb) - 2,height(lb) - 2);
-	p->drawRect(2,2,width(lb) - 4,height(lb) - 4);
-#else
 	p->drawWinFocusRect(0,0,width(lb),height(lb),clr);
 	p->drawWinFocusRect(1,1,width(lb) - 2,height(lb) - 2,clr);
 	p->drawWinFocusRect(2,2,width(lb) - 4,height(lb) - 4,clr);
-#endif
 	}
 }
 /*
@@ -399,11 +382,7 @@ KviMessageColorsOptionsWidget::KviMessageColorsOptionsWidget(TQWidget * parent)
 	m_pListView->setSelectionMode(KviTalListView::Single);
 	m_pListView->setFont(KVI_OPTION_FONT(KviOption_fontIrcView));
 	m_pListView->setStaticBackground(true);
-#ifdef COMPILE_USE_QT4
-	m_pListView->viewport()->setBackgroundMode(TQt::NoBackground);
-#else
 	m_pListView->viewport()->setBackgroundMode(TQWidget::NoBackground);
-#endif
 
 	addWidgetToLayout(m_pListView,0,0,2,0);
 
