@@ -202,12 +202,7 @@ KviSinglePopupEditor::KviSinglePopupEditor(TQWidget * par)
 	m_pMenuButton = new TQPushButton(__tr2qs("Test"),this);
 	g->addWidget(m_pMenuButton,0,2);
 	connect(m_pMenuButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(testPopup()));
-#ifdef COMPILE_USE_QT4
-	TQSplitter * spl = new TQSplitter(Qt::Vertical,this,"popupeditor");
-	spl->setOpaqueResize(false);
-#else
 	TQSplitter * spl = new TQSplitter(Qt::Vertical,this);
-#endif
 
 	m_pListView = new KviTalListView(spl);
 	m_pListView->addColumn(__tr2qs("Item"));
@@ -1028,12 +1023,7 @@ KviPopupEditor::KviPopupEditor(TQWidget * par)
 : TQWidget(par)
 {
 	TQGridLayout * l = new TQGridLayout(this,1,1,0,2);
-#ifdef COMPILE_USE_QT4
-	TQSplitter * spl = new TQSplitter(Qt::Horizontal,this,"popupeditor");
-	spl->setOpaqueResize(false);
-#else
 	TQSplitter * spl = new TQSplitter(Qt::Horizontal,this);
-#endif
 	l->addWidget(spl,0,0);
 	
 	KviTalVBox * box = new KviTalVBox(spl);
