@@ -74,12 +74,7 @@ KviRawEditor::KviRawEditor(TQWidget * par)
 : TQWidget(par,"raw_event_editor")
 {
 	TQGridLayout * l = new TQGridLayout(this,1,1,2,2);
-#ifdef COMPILE_USE_QT4
-	TQSplitter * spl = new TQSplitter(Qt::Horizontal,this,"raweditorv");
-	spl->setOpaqueResize(false);
-#else
 	TQSplitter * spl = new TQSplitter(Qt::Horizontal,this);
-#endif
 	l->addWidget(spl,0,0);
 
 	KviTalVBox * boxi = new KviTalVBox(spl);
