@@ -44,13 +44,7 @@
 #include <tqlayout.h>
 #include <tqlabel.h>
 #include <tqgroupbox.h>
-#ifdef COMPILE_USE_QT4
-#include <tqevent.h>
-#include <tq3header.h>
-#include <tq3vbox.h>
-#else
 #include <tqheader.h>
-#endif
 #include "kvi_pointerhashtable.h"
 #include <tqimage.h>
 #include <tqstring.h>
@@ -88,11 +82,7 @@ KviReguserPropertiesDialog::KviReguserPropertiesDialog(TQWidget * p,KviPointerHa
 
 	TQGridLayout * g = new TQGridLayout(this,3,3,4,4);
 
-#ifdef COMPILE_USE_QT4
-	m_pTable = new Q3Table(this);
-#else
 	m_pTable = new TQTable(this);
-#endif
 	g->addMultiCellWidget(m_pTable,0,1,0,1);
 
 	m_pTable->setNumCols(2);
@@ -448,11 +438,7 @@ KviRegisteredUserEntryDialog::KviRegisteredUserEntryDialog(TQWidget *p,KviRegist
 	addTab(p2,__tr2qs("Properties"));
 
 	// Ignore TAB
-#ifdef COMPILE_USE_QT4
-	Q3VBox * vb = new Q3VBox(this);
-#else
 	TQVBox * vb = new TQVBox(this);
-#endif
 	vb->setMargin(10);
 
 	m_pIgnoreEnabled = new KviStyledCheckBox(__tr2qs("Enable ignore for this user"),vb);
@@ -597,7 +583,7 @@ void KviRegisteredUserEntryDialog::okClicked()
 	{
 		// ops... no way
 		// FIXME: spit an error message ?
-		debug("Ops.. something wrong with the regusers db");
+		tqDebug("Ops.. something wrong with the regusers db");
 		accept();
 		return;
 	}
