@@ -55,9 +55,6 @@ bool g_bFoundMirc;
 	#include <unistd.h>  // for symlink()
 #endif
 
-#ifdef COMPILE_USE_QT4
-	#include <TQDesktopWidget>
-#endif
 
 // libkvisetup.cpp
 extern TQString g_szChoosenIncomingDirectory;
@@ -125,9 +122,6 @@ KviSetupPage::KviSetupPage(KviSetupWizard * w)
 	l->setBackgroundColor(TQColor(48,48,48));
 
 	m_pTextLabel = new TQLabel(m_pVBox);
-#ifdef COMPILE_USE_QT4
-	m_pTextLabel->setWordWrap(true);
-#endif
 	m_pTextLabel->setAlignment(TQt::AlignJustify | TQt::AlignTop);
 	m_pVBox->setStretchFactor(m_pTextLabel,1);
 }
