@@ -56,7 +56,7 @@ public:
 
 class KviSharedFileEditDialog : public TQDialog
 { 
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviSharedFileEditDialog(TQWidget* par,KviSharedFile * f = 0);
@@ -81,7 +81,7 @@ protected slots:
 class KviSharedFilesWindow : public KviWindow , public KviModuleExtension
 {
 	friend class KviSharedFilesItem;
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviSharedFilesWindow(KviModuleExtensionDescriptor * d,KviFrame * lpFrm);
